@@ -18,14 +18,16 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "gtksourcemap.h"
-#include <string.h>
 #include "gtksourcebuffer.h"
 #include "gtksourcecompletion.h"
+#include "gtksourcemap.h"
 #include "gtksourcestyle-private.h"
 #include "gtksourcestylescheme.h"
 #include "gtksourceview-utils.h"
 
+#include <glib/gi18n.h>
+#include <string.h>
+
 /**
  * SECTION:map
  * @Short_description: Widget that displays a map for a specific #GtkSourceView
@@ -217,10 +219,7 @@ update_scrubber_position (GtkSourceMap *map)
 	scrubber_area.x = 0;
 	scrubber_area.width = alloc.width;
 	scrubber_area.y = y;
-	scrubber_area.height = ((gdouble)view_alloc.height /
-	                        (gdouble)view_height *
-	                        (gdouble)child_height) +
-	                       iter_area.height;
+	scrubber_area.height = (gdouble)view_alloc.height / (gdouble)view_height * (gdouble)child_height;
 
 	if (memcmp (&scrubber_area, &priv->scrubber_area, sizeof scrubber_area) != 0)
 	{
@@ -1073,15 +1072,15 @@ gtk_source_map_class_init (GtkSourceMapClass *klass)
 
 	pspecs[PROP_VIEW] =
 		g_param_spec_object ("view",
-		                     "View",
-		                     "The view this widget is mapping.",
+		                     _("View"),
+		                     _("The view this widget is mapping."),
 		                     GTK_SOURCE_TYPE_VIEW,
 		                     (G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	pspecs[PROP_FONT_DESC] =
 		g_param_spec_boxed ("font-desc",
-		                    "Font Description",
-		                    "The Pango font description to use.",
+		                    _("Font Description"),
+		                    _("The Pango font description to use."),
 		                    PANGO_TYPE_FONT_DESCRIPTION,
 		                    (G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
