@@ -440,7 +440,8 @@ fix_style_colors (GtkSourceStyleScheme *scheme,
 	} attributes[] = {
 		{ GTK_SOURCE_STYLE_USE_BACKGROUND, G_STRUCT_OFFSET (GtkSourceStyle, background) },
 		{ GTK_SOURCE_STYLE_USE_FOREGROUND, G_STRUCT_OFFSET (GtkSourceStyle, foreground) },
-		{ GTK_SOURCE_STYLE_USE_LINE_BACKGROUND, G_STRUCT_OFFSET (GtkSourceStyle, line_background) }
+		{ GTK_SOURCE_STYLE_USE_LINE_BACKGROUND, G_STRUCT_OFFSET (GtkSourceStyle, line_background) },
+		{ GTK_SOURCE_STYLE_USE_UNDERLINE_COLOR, G_STRUCT_OFFSET (GtkSourceStyle, underline_color) }
 	};
 
 	style = gtk_source_style_copy (real_style);
@@ -635,8 +636,8 @@ get_cursors_css_style (GtkSourceStyleScheme *scheme,
 {
 	GtkSourceStyle *primary_style;
 	GtkSourceStyle *secondary_style;
-	GdkRGBA primary_color;
-	GdkRGBA secondary_color;
+	GdkRGBA primary_color = { 0 };
+	GdkRGBA secondary_color = { 0 };
 	gchar *primary_color_str;
 	gchar *secondary_color_str;
 	gchar *css;
@@ -655,9 +656,10 @@ get_cursors_css_style (GtkSourceStyleScheme *scheme,
 
 		context = gtk_widget_get_style_context (widget);
 
-		gtk_style_context_get_background_color (context,
-							GTK_STATE_FLAG_NORMAL,
-		                                        &secondary_color);
+		gtk_style_context_get (context,
+				       GTK_STATE_FLAG_NORMAL,
+				       "background-color", &secondary_color,
+				       NULL);
 
 		/* shade the secondary cursor */
 		secondary_color.red *= 0.5;
@@ -742,7 +744,7 @@ _gtk_source_style_scheme_apply (GtkSourceStyleScheme *scheme,
 	context = gtk_widget_get_style_context (GTK_WIDGET (widget));
 	gtk_style_context_add_provider (context,
 	                                GTK_STYLE_PROVIDER (scheme->priv->css_provider),
-	                                GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+	                                GTK_SOURCE_STYLE_PROVIDER_PRIORITY);
 
 	G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
 	/* See https://bugzilla.gnome.org/show_bug.cgi?id=708583 */
@@ -761,7 +763,7 @@ _gtk_source_style_scheme_apply (GtkSourceStyleScheme *scheme,
 	{
 		gtk_style_context_add_provider (context,
 						GTK_STYLE_PROVIDER (scheme->priv->css_provider_cursors),
-						GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+						GTK_SOURCE_STYLE_PROVIDER_PRIORITY);
 
 		G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
 		gtk_style_context_invalidate (context);
@@ -920,6 +922,14 @@ generate_css_style (GtkSourceStyleScheme *scheme)
 	g_string_free (final_style, TRUE);
 }
 
+static gboolean
+parse_bool (char *value)
+{
+	return (g_ascii_strcasecmp (value, "true") == 0 ||
+	        g_ascii_strcasecmp (value, "yes") == 0 ||
+	        g_ascii_strcasecmp (value, "1") == 0);
+}
+
 static void
 get_bool (xmlNode    *node,
 	  const char *propname,
@@ -932,9 +942,7 @@ get_bool (xmlNode    *node,
 	if (tmp != NULL)
 	{
 		*mask |= mask_value;
-		*value = g_ascii_strcasecmp ((char*) tmp, "true") == 0 ||
-			 g_ascii_strcasecmp ((char*) tmp, "yes") == 0 ||
-			 g_ascii_strcasecmp ((char*) tmp, "1") == 0;
+		*value = parse_bool ((char*) tmp);
 	}
 
 	xmlFree (tmp);
@@ -956,8 +964,9 @@ parse_style (GtkSourceStyleScheme *scheme,
 	guint mask = 0;
 	gboolean bold = FALSE;
 	gboolean italic = FALSE;
-	gboolean underline = FALSE;
 	gboolean strikethrough = FALSE;
+	xmlChar *underline = NULL;
+	xmlChar *underline_color = NULL;
 	xmlChar *scale = NULL;
 	xmlChar *tmp;
 
@@ -1003,13 +1012,20 @@ parse_style (GtkSourceStyleScheme *scheme,
 	line_bg = xmlGetProp (node, BAD_CAST "line-background");
 	get_bool (node, "italic", &mask, GTK_SOURCE_STYLE_USE_ITALIC, &italic);
 	get_bool (node, "bold", &mask, GTK_SOURCE_STYLE_USE_BOLD, &bold);
-	get_bool (node, "underline", &mask, GTK_SOURCE_STYLE_USE_UNDERLINE, &underline);
 	get_bool (node, "strikethrough", &mask, GTK_SOURCE_STYLE_USE_STRIKETHROUGH, &strikethrough);
+	underline = xmlGetProp (node, BAD_CAST "underline");
+	underline_color = xmlGetProp (node, BAD_CAST "underline-color");
 	scale = xmlGetProp (node, BAD_CAST "scale");
 
 	if (use_style)
 	{
-		if (fg != NULL || bg != NULL || line_bg != NULL || mask != 0 || scale != NULL)
+		if (fg != NULL ||
+		    bg != NULL ||
+		    line_bg != NULL ||
+		    mask != 0 ||
+		    underline != NULL ||
+		    underline_color != NULL ||
+		    scale != NULL)
 		{
 			g_set_error (error, ERROR_QUARK, 0,
 				     "in style '%s': style attributes used along with use-style",
@@ -1019,6 +1035,9 @@ parse_style (GtkSourceStyleScheme *scheme,
 			xmlFree (fg);
 			xmlFree (bg);
 			xmlFree (line_bg);
+			xmlFree (underline);
+			xmlFree (underline_color);
+			xmlFree (scale);
 			return FALSE;
 		}
 
@@ -1032,7 +1051,6 @@ parse_style (GtkSourceStyleScheme *scheme,
 		result->mask = mask;
 		result->bold = bold;
 		result->italic = italic;
-		result->underline = underline;
 		result->strikethrough = strikethrough;
 
 		if (fg != NULL)
@@ -1052,6 +1070,45 @@ parse_style (GtkSourceStyleScheme *scheme,
 			result->line_background = g_intern_string ((char*) line_bg);
 			result->mask |= GTK_SOURCE_STYLE_USE_LINE_BACKGROUND;
 		}
+
+		if (underline != NULL)
+		{
+			/* Up until 3.16 underline was a "bool", so for backward
+			 * compat we accept underline="true" and map it to "single"
+			 */
+			if (parse_bool ((char *) underline))
+			{
+				result->underline = PANGO_UNDERLINE_SINGLE;
+				result->mask |= GTK_SOURCE_STYLE_USE_UNDERLINE;
+			}
+			else
+			{
+				GEnumClass *enum_class;
+				GEnumValue *enum_value;
+				gchar *underline_lowercase;
+
+				enum_class = G_ENUM_CLASS (g_type_class_ref (PANGO_TYPE_UNDERLINE));
+
+				underline_lowercase = g_ascii_strdown ((char*) underline, -1);
+				enum_value = g_enum_get_value_by_nick (enum_class, underline_lowercase);
+				g_free (underline_lowercase);
+
+				if (enum_value != NULL)
+				{
+					result->underline = enum_value->value;
+					result->mask |= GTK_SOURCE_STYLE_USE_UNDERLINE;
+				}
+
+				g_type_class_unref (enum_class);
+			}
+		}
+
+		if (underline_color != NULL)
+		{
+			result->underline_color = g_intern_string ((char*) underline_color);
+			result->mask |= GTK_SOURCE_STYLE_USE_UNDERLINE_COLOR;
+		}
+
 		if (scale != NULL)
 		{
 			result->scale = g_intern_string ((char*) scale);
@@ -1062,10 +1119,12 @@ parse_style (GtkSourceStyleScheme *scheme,
 	*style_p = result;
 	*style_name_p = style_name;
 
-	xmlFree (scale);
-	xmlFree (line_bg);
-	xmlFree (bg);
 	xmlFree (fg);
+	xmlFree (bg);
+	xmlFree (line_bg);
+	xmlFree (underline);
+	xmlFree (underline_color);
+	xmlFree (scale);
 
 	return TRUE;
 }
