@@ -197,10 +197,10 @@ test_provider_set_fixed (TestProvider *provider,
 	}
 
 	proposals = g_list_prepend (proposals,
-				    gtk_source_completion_item_new ("A very long proposal. I repeat, a very long proposal!",
-								    "A very long proposal. I repeat, a very long proposal!",
-								    icon,
-								    "To test the horizontal scrollbar."));
+				    gtk_source_completion_item_new_with_markup ("A very <b>long</b> proposal. I <i>repeat</i>, a very long proposal!",
+										"A very long proposal. I repeat, a very long proposal!",
+										icon,
+										"To test the horizontal scrollbar and the markup."));
 
 	provider->proposals = proposals;
 	provider->is_random = 0;
@@ -349,7 +349,6 @@ create_window (void)
 	GtkCheckButton *enable_random_provider;
 	GtkSpinButton *nb_fixed_proposals;
 	GtkSpinButton *nb_random_proposals;
-	PangoFontDescription *font_desc;
 
 	builder = gtk_builder_new ();
 
@@ -376,13 +375,6 @@ create_window (void)
 
 	completion = gtk_source_view_get_completion (source_view);
 
-	font_desc = pango_font_description_from_string ("monospace");
-	if (font_desc != NULL)
-	{
-		gtk_widget_override_font (GTK_WIDGET (source_view), font_desc);
-		pango_font_description_free (font_desc);
-	}
-
 	g_signal_connect (window,
 			  "destroy",
 			  G_CALLBACK (gtk_main_quit),
